# Copyright © inria 2009-2010
# Brice Goglin <Brice.Goglin@inria.fr>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%define kmod_name knem

Name:		%{kmod_name}
Version:	1.1.2
Release:	2%{?dist}
Summary:	High-Performance Intra-Node MPI Communication
License:	BSD
Group:		System Environment/Kernel
URL:		http://knem.gforge.inria.fr/
Source0:        %{kmod_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	hwloc-devel
BuildRequires:	%kernel_module_package_buildreqs
%kernel_module_package -n %{kmod_name}

%description 
KNEM is a Linux kernel module enabling high-performance intra-node MPI
communication for large messages. KNEM works on all Linux kernel since 
2.6.15 and offers support for asynchronous and vectorial data transfers
as well as offloading memory copies on to Intel I/OAT hardware.

%prep
%setup -q -c -n %{kmod_name}-kmod-%{version}
mv %{kmod_name}-%{version} source
ln -s /bin/true aclocal-1.14
ln -s /bin/true automake-1.14
ln -s /bin/true autoconf
cd source
mv missing missing.disabled
ln -s /bin/true missing


%build
export PATH=`pwd`:$PATH
for flavor in %flavors_to_build ; do
	echo Building for $flavor and target cpu %{_target_cpu} and kverrel = %kverrel
	cp -r source $flavor
	pushd $flavor
	%configure --with-linux-build=%{kernel_source $flavor}
	make
	#make -C %{kernel_source $flavor} M=$PWD/driver/linux modules
	popd
done

%install
export PATH=`pwd`:$PATH
# first install default
pushd default
%makeinstall
popd
# we do not want this one
rm -f $RPM_BUILD_ROOT%{_sbindir}/knem_local_install
# and this one we will package separately
rm -rf $RPM_BUILD_ROOT/usr/share/doc
# also we will install knem below
rm -rf $RPM_BUILD_ROOT%{_libdir}/modules
mkdir -p $RPM_BUILD_ROOT/etc/udev/rules.d
mv $RPM_BUILD_ROOT/etc/10-knem.rules $RPM_BUILD_ROOT/etc/udev/rules.d/10-knem.rules
# now allow everyone access
perl -pi -e 's|^KERNEL|#KERNEL|,s|^#KERNEL(.*)MODE|KERNEL\1MODE|' $RPM_BUILD_ROOT/etc/udev/rules.d/10-knem.rules
# now install modules properly
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=extra/%{kmod_name}
for flavor in %flavors_to_build ; do
	make -C %{kernel_source $flavor} modules_install M=$PWD/$flavor/driver/linux SUBDIRS=$PWD/$flavor/driver/linux
done
chmod -R u+w,a+rX,og-w $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc source/AUTHORS source/COPYING source/doc/*.html source/README*
%{_bindir}/knem*
%{_includedir}/knem_io.h
%config(noreplace) /etc/udev/rules.d/10-knem.rules

%changelog
* Sat Feb 14 2015 Josko Plazonic <plazonic@princeton.edu>
- initial build
